==> istio-model-v1alpha3-6.6.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterSpecFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterSpecFluentImpl<A extends EnvoyFilterSpecFluent<A>> extends BaseFluent<A> implements EnvoyFilterSpecFluent<A>{
  public EnvoyFilterSpecFluentImpl() {
  }
  public EnvoyFilterSpecFluentImpl(EnvoyFilterSpec instance) {
    this.withConfigPatches(instance.getConfigPatches()); 
    this.withPriority(instance.getPriority()); 
    this.withWorkloadSelector(instance.getWorkloadSelector()); 
  }
  private ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder> configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();
  private Integer priority;
  private WorkloadSelectorBuilder workloadSelector;
  public A addToConfigPatches(Integer index,EnvoyFilterEnvoyConfigObjectPatch item) {
    if (this.configPatches == null) {this.configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();}
    EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").add(index >= 0 ? index : _visitables.get("configPatches").size(), builder);this.configPatches.add(index >= 0 ? index : configPatches.size(), builder); return (A)this;
  }
  public A setToConfigPatches(Integer index,EnvoyFilterEnvoyConfigObjectPatch item) {
    if (this.configPatches == null) {this.configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();}
    EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);
    if (index < 0 || index >= _visitables.get("configPatches").size()) { _visitables.get("configPatches").add(builder); } else { _visitables.get("configPatches").set(index, builder);}
    if (index < 0 || index >= configPatches.size()) { configPatches.add(builder); } else { configPatches.set(index, builder);}
     return (A)this;
  }
  public A addToConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... items) {
    if (this.configPatches == null) {this.configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();}
    for (EnvoyFilterEnvoyConfigObjectPatch item : items) {EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").add(builder);this.configPatches.add(builder);} return (A)this;
  }
  public A addAllToConfigPatches(Collection<EnvoyFilterEnvoyConfigObjectPatch> items) {
    if (this.configPatches == null) {this.configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();}
    for (EnvoyFilterEnvoyConfigObjectPatch item : items) {EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").add(builder);this.configPatches.add(builder);} return (A)this;
  }
  public A removeFromConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... items) {
    for (EnvoyFilterEnvoyConfigObjectPatch item : items) {EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").remove(builder);if (this.configPatches != null) {this.configPatches.remove(builder);}} return (A)this;
  }
  public A removeAllFromConfigPatches(Collection<EnvoyFilterEnvoyConfigObjectPatch> items) {
    for (EnvoyFilterEnvoyConfigObjectPatch item : items) {EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").remove(builder);if (this.configPatches != null) {this.configPatches.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromConfigPatches(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate) {
    if (configPatches == null) return (A) this;
    final Iterator<EnvoyFilterEnvoyConfigObjectPatchBuilder> each = configPatches.iterator();
    final List visitables = _visitables.get("configPatches");
    while (each.hasNext()) {
      EnvoyFilterEnvoyConfigObjectPatchBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildConfigPatches instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<EnvoyFilterEnvoyConfigObjectPatch> getConfigPatches() {
    return configPatches != null ? build(configPatches) : null;
  }
  public List<EnvoyFilterEnvoyConfigObjectPatch> buildConfigPatches() {
    return configPatches != null ? build(configPatches) : null;
  }
  public EnvoyFilterEnvoyConfigObjectPatch buildConfigPatch(Integer index) {
    return this.configPatches.get(index).build();
  }
  public EnvoyFilterEnvoyConfigObjectPatch buildFirstConfigPatch() {
    return this.configPatches.get(0).build();
  }
  public EnvoyFilterEnvoyConfigObjectPatch buildLastConfigPatch() {
    return this.configPatches.get(configPatches.size() - 1).build();
  }
  public EnvoyFilterEnvoyConfigObjectPatch buildMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate) {
    for (EnvoyFilterEnvoyConfigObjectPatchBuilder item: configPatches) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate) {
    for (EnvoyFilterEnvoyConfigObjectPatchBuilder item: configPatches) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConfigPatches(List<EnvoyFilterEnvoyConfigObjectPatch> configPatches) {
    if (this.configPatches != null) { _visitables.get("configPatches").removeAll(this.configPatches);}
    if (configPatches != null) {this.configPatches = new ArrayList(); for (EnvoyFilterEnvoyConfigObjectPatch item : configPatches){this.addToConfigPatches(item);}} else { this.configPatches = null;} return (A) this;
  }
  public A withConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... configPatches) {
    if (this.configPatches != null) {this.configPatches.clear();}
    if (configPatches != null) {for (EnvoyFilterEnvoyConfigObjectPatch item :configPatches){ this.addToConfigPatches(item);}} return (A) this;
  }
  public Boolean hasConfigPatches() {
    return configPatches != null && !configPatches.isEmpty();
  }
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> addNewConfigPatch() {
    return new EnvoyFilterSpecFluentImpl.ConfigPatchesNestedImpl();
  }
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> addNewConfigPatchLike(EnvoyFilterEnvoyConfigObjectPatch item) {
    return new EnvoyFilterSpecFluentImpl.ConfigPatchesNestedImpl(-1, item);
  }
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> setNewConfigPatchLike(Integer index,EnvoyFilterEnvoyConfigObjectPatch item) {
    return new EnvoyFilterSpecFluentImpl.ConfigPatchesNestedImpl(index, item);
  }
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> editConfigPatch(Integer index) {
    if (configPatches.size() <= index) throw new RuntimeException("Can't edit configPatches. Index exceeds size.");
    return setNewConfigPatchLike(index, buildConfigPatch(index));
  }
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> editFirstConfigPatch() {
    if (configPatches.size() == 0) throw new RuntimeException("Can't edit first configPatches. The list is empty.");
    return setNewConfigPatchLike(0, buildConfigPatch(0));
  }
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> editLastConfigPatch() {
    int index = configPatches.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last configPatches. The list is empty.");
    return setNewConfigPatchLike(index, buildConfigPatch(index));
  }
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> editMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate) {
    int index = -1;
    for (int i=0;i<configPatches.size();i++) { 
    if (predicate.test(configPatches.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching configPatches. No match found.");
    return setNewConfigPatchLike(index, buildConfigPatch(index));
  }
  public Integer getPriority() {
    return this.priority;
  }
  public A withPriority(Integer priority) {
    this.priority=priority; return (A) this;
  }
  public Boolean hasPriority() {
    return this.priority != null;
  }
  
  /**
   * This method has been deprecated, please use method buildWorkloadSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public WorkloadSelector getWorkloadSelector() {
    return this.workloadSelector!=null ?this.workloadSelector.build():null;
  }
  public WorkloadSelector buildWorkloadSelector() {
    return this.workloadSelector!=null ?this.workloadSelector.build():null;
  }
  public A withWorkloadSelector(WorkloadSelector workloadSelector) {
    _visitables.get("workloadSelector").remove(this.workloadSelector);
    if (workloadSelector!=null){ this.workloadSelector= new WorkloadSelectorBuilder(workloadSelector); _visitables.get("workloadSelector").add(this.workloadSelector);} else { this.workloadSelector = null; _visitables.get("workloadSelector").remove(this.workloadSelector); } return (A) this;
  }
  public Boolean hasWorkloadSelector() {
    return this.workloadSelector != null;
  }
  public EnvoyFilterSpecFluent.WorkloadSelectorNested<A> withNewWorkloadSelector() {
    return new EnvoyFilterSpecFluentImpl.WorkloadSelectorNestedImpl();
  }
  public EnvoyFilterSpecFluent.WorkloadSelectorNested<A> withNewWorkloadSelectorLike(WorkloadSelector item) {
    return new EnvoyFilterSpecFluentImpl.WorkloadSelectorNestedImpl(item);
  }
  public EnvoyFilterSpecFluent.WorkloadSelectorNested<A> editWorkloadSelector() {
    return withNewWorkloadSelectorLike(getWorkloadSelector());
  }
  public EnvoyFilterSpecFluent.WorkloadSelectorNested<A> editOrNewWorkloadSelector() {
    return withNewWorkloadSelectorLike(getWorkloadSelector() != null ? getWorkloadSelector(): new WorkloadSelectorBuilder().build());
  }
  public EnvoyFilterSpecFluent.WorkloadSelectorNested<A> editOrNewWorkloadSelectorLike(WorkloadSelector item) {
    return withNewWorkloadSelectorLike(getWorkloadSelector() != null ? getWorkloadSelector(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvoyFilterSpecFluentImpl that = (EnvoyFilterSpecFluentImpl) o;
    if (configPatches != null ? !configPatches.equals(that.configPatches) :that.configPatches != null) return false;
    if (priority != null ? !priority.equals(that.priority) :that.priority != null) return false;
    if (workloadSelector != null ? !workloadSelector.equals(that.workloadSelector) :that.workloadSelector != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(configPatches,  priority,  workloadSelector,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (configPatches != null && !configPatches.isEmpty()) { sb.append("configPatches:"); sb.append(configPatches + ","); }
    if (priority != null) { sb.append("priority:"); sb.append(priority + ","); }
    if (workloadSelector != null) { sb.append("workloadSelector:"); sb.append(workloadSelector); }
    sb.append("}");
    return sb.toString();
  }
  class ConfigPatchesNestedImpl<N> extends EnvoyFilterEnvoyConfigObjectPatchFluentImpl<EnvoyFilterSpecFluent.ConfigPatchesNested<N>> implements EnvoyFilterSpecFluent.ConfigPatchesNested<N>,Nested<N>{
    ConfigPatchesNestedImpl(Integer index,EnvoyFilterEnvoyConfigObjectPatch item) {
      this.index = index;
      this.builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(this, item);
    }
    ConfigPatchesNestedImpl() {
      this.index = -1;
      this.builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(this);
    }
    EnvoyFilterEnvoyConfigObjectPatchBuilder builder;
    Integer index;
    public N and() {
      return (N) EnvoyFilterSpecFluentImpl.this.setToConfigPatches(index,builder.build());
    }
    public N endConfigPatch() {
      return and();
    }
    
  }
  class WorkloadSelectorNestedImpl<N> extends WorkloadSelectorFluentImpl<EnvoyFilterSpecFluent.WorkloadSelectorNested<N>> implements EnvoyFilterSpecFluent.WorkloadSelectorNested<N>,Nested<N>{
    WorkloadSelectorNestedImpl(WorkloadSelector item) {
      this.builder = new WorkloadSelectorBuilder(this, item);
    }
    WorkloadSelectorNestedImpl() {
      this.builder = new WorkloadSelectorBuilder(this);
    }
    WorkloadSelectorBuilder builder;
    public N and() {
      return (N) EnvoyFilterSpecFluentImpl.this.withWorkloadSelector(builder.build());
    }
    public N endWorkloadSelector() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterSpecFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterSpecFluentImpl<A extends EnvoyFilterSpecFluent<A>> extends BaseFluent<A> implements EnvoyFilterSpecFluent<A>{
  public EnvoyFilterSpecFluentImpl() {
  }
  public EnvoyFilterSpecFluentImpl(EnvoyFilterSpec instance) {
    if (instance != null) {
      this.withConfigPatches(instance.getConfigPatches());
      this.withPriority(instance.getPriority());
      this.withWorkloadSelector(instance.getWorkloadSelector());
    }
  }
  private ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder> configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();
  private Integer priority;
  private WorkloadSelectorBuilder workloadSelector;
  public A addToConfigPatches(int index,EnvoyFilterEnvoyConfigObjectPatch item) {
    if (this.configPatches == null) {this.configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();}
    EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);
    if (index < 0 || index >= configPatches.size()) { _visitables.get("configPatches").add(builder); configPatches.add(builder); } else { _visitables.get("configPatches").add(index, builder); configPatches.add(index, builder);}
    return (A)this;
  }
  public A setToConfigPatches(int index,EnvoyFilterEnvoyConfigObjectPatch item) {
    if (this.configPatches == null) {this.configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();}
    EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);
    if (index < 0 || index >= configPatches.size()) { _visitables.get("configPatches").add(builder); configPatches.add(builder); } else { _visitables.get("configPatches").set(index, builder); configPatches.set(index, builder);}
    return (A)this;
  }
  public A addToConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... items) {
    if (this.configPatches == null) {this.configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();}
    for (EnvoyFilterEnvoyConfigObjectPatch item : items) {EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").add(builder);this.configPatches.add(builder);} return (A)this;
  }
  public A addAllToConfigPatches(Collection<EnvoyFilterEnvoyConfigObjectPatch> items) {
    if (this.configPatches == null) {this.configPatches = new ArrayList<EnvoyFilterEnvoyConfigObjectPatchBuilder>();}
    for (EnvoyFilterEnvoyConfigObjectPatch item : items) {EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").add(builder);this.configPatches.add(builder);} return (A)this;
  }
  public A removeFromConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... items) {
    for (EnvoyFilterEnvoyConfigObjectPatch item : items) {EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").remove(builder);if (this.configPatches != null) {this.configPatches.remove(builder);}} return (A)this;
  }
  public A removeAllFromConfigPatches(Collection<EnvoyFilterEnvoyConfigObjectPatch> items) {
    for (EnvoyFilterEnvoyConfigObjectPatch item : items) {EnvoyFilterEnvoyConfigObjectPatchBuilder builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(item);_visitables.get("configPatches").remove(builder);if (this.configPatches != null) {this.configPatches.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromConfigPatches(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate) {
    if (configPatches == null) return (A) this;
    final Iterator<EnvoyFilterEnvoyConfigObjectPatchBuilder> each = configPatches.iterator();
    final List visitables = _visitables.get("configPatches");
    while (each.hasNext()) {
      EnvoyFilterEnvoyConfigObjectPatchBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildConfigPatches instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<EnvoyFilterEnvoyConfigObjectPatch> getConfigPatches() {
    return configPatches != null ? build(configPatches) : null;
  }
  public List<EnvoyFilterEnvoyConfigObjectPatch> buildConfigPatches() {
    return configPatches != null ? build(configPatches) : null;
  }
  public EnvoyFilterEnvoyConfigObjectPatch buildConfigPatch(int index) {
    return this.configPatches.get(index).build();
  }
  public EnvoyFilterEnvoyConfigObjectPatch buildFirstConfigPatch() {
    return this.configPatches.get(0).build();
  }
  public EnvoyFilterEnvoyConfigObjectPatch buildLastConfigPatch() {
    return this.configPatches.get(configPatches.size() - 1).build();
  }
  public EnvoyFilterEnvoyConfigObjectPatch buildMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate) {
    for (EnvoyFilterEnvoyConfigObjectPatchBuilder item: configPatches) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate) {
    for (EnvoyFilterEnvoyConfigObjectPatchBuilder item: configPatches) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConfigPatches(List<EnvoyFilterEnvoyConfigObjectPatch> configPatches) {
    if (this.configPatches != null) { _visitables.get("configPatches").clear();}
    if (configPatches != null) {this.configPatches = new ArrayList(); for (EnvoyFilterEnvoyConfigObjectPatch item : configPatches){this.addToConfigPatches(item);}} else { this.configPatches = null;} return (A) this;
  }
  public A withConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... configPatches) {
    if (this.configPatches != null) {this.configPatches.clear(); _visitables.remove("configPatches"); }
    if (configPatches != null) {for (EnvoyFilterEnvoyConfigObjectPatch item :configPatches){ this.addToConfigPatches(item);}} return (A) this;
  }
  public Boolean hasConfigPatches() {
    return configPatches != null && !configPatches.isEmpty();
  }
  public EnvoyFilterSpecFluentImpl.ConfigPatchesNested<A> addNewConfigPatch() {
    return new EnvoyFilterSpecFluentImpl.ConfigPatchesNestedImpl();
  }
  public EnvoyFilterSpecFluentImpl.ConfigPatchesNested<A> addNewConfigPatchLike(EnvoyFilterEnvoyConfigObjectPatch item) {
    return new EnvoyFilterSpecFluentImpl.ConfigPatchesNestedImpl(-1, item);
  }
  public EnvoyFilterSpecFluentImpl.ConfigPatchesNested<A> setNewConfigPatchLike(int index,EnvoyFilterEnvoyConfigObjectPatch item) {
    return new EnvoyFilterSpecFluentImpl.ConfigPatchesNestedImpl(index, item);
  }
  public EnvoyFilterSpecFluentImpl.ConfigPatchesNested<A> editConfigPatch(int index) {
    if (configPatches.size() <= index) throw new RuntimeException("Can't edit configPatches. Index exceeds size.");
    return setNewConfigPatchLike(index, buildConfigPatch(index));
  }
  public EnvoyFilterSpecFluentImpl.ConfigPatchesNested<A> editFirstConfigPatch() {
    if (configPatches.size() == 0) throw new RuntimeException("Can't edit first configPatches. The list is empty.");
    return setNewConfigPatchLike(0, buildConfigPatch(0));
  }
  public EnvoyFilterSpecFluentImpl.ConfigPatchesNested<A> editLastConfigPatch() {
    int index = configPatches.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last configPatches. The list is empty.");
    return setNewConfigPatchLike(index, buildConfigPatch(index));
  }
  public EnvoyFilterSpecFluentImpl.ConfigPatchesNested<A> editMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate) {
    int index = -1;
    for (int i=0;i<configPatches.size();i++) { 
    if (predicate.test(configPatches.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching configPatches. No match found.");
    return setNewConfigPatchLike(index, buildConfigPatch(index));
  }
  public Integer getPriority() {
    return this.priority;
  }
  public A withPriority(Integer priority) {
    this.priority=priority; return (A) this;
  }
  public Boolean hasPriority() {
    return this.priority != null;
  }
  
  /**
   * This method has been deprecated, please use method buildWorkloadSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public WorkloadSelector getWorkloadSelector() {
    return this.workloadSelector!=null ?this.workloadSelector.build():null;
  }
  public WorkloadSelector buildWorkloadSelector() {
    return this.workloadSelector!=null ?this.workloadSelector.build():null;
  }
  public A withWorkloadSelector(WorkloadSelector workloadSelector) {
    _visitables.get("workloadSelector").remove(this.workloadSelector);
    if (workloadSelector!=null){ this.workloadSelector= new WorkloadSelectorBuilder(workloadSelector); _visitables.get("workloadSelector").add(this.workloadSelector);} else { this.workloadSelector = null; _visitables.get("workloadSelector").remove(this.workloadSelector); } return (A) this;
  }
  public Boolean hasWorkloadSelector() {
    return this.workloadSelector != null;
  }
  public EnvoyFilterSpecFluentImpl.WorkloadSelectorNested<A> withNewWorkloadSelector() {
    return new EnvoyFilterSpecFluentImpl.WorkloadSelectorNestedImpl();
  }
  public EnvoyFilterSpecFluentImpl.WorkloadSelectorNested<A> withNewWorkloadSelectorLike(WorkloadSelector item) {
    return new EnvoyFilterSpecFluentImpl.WorkloadSelectorNestedImpl(item);
  }
  public EnvoyFilterSpecFluentImpl.WorkloadSelectorNested<A> editWorkloadSelector() {
    return withNewWorkloadSelectorLike(getWorkloadSelector());
  }
  public EnvoyFilterSpecFluentImpl.WorkloadSelectorNested<A> editOrNewWorkloadSelector() {
    return withNewWorkloadSelectorLike(getWorkloadSelector() != null ? getWorkloadSelector(): new WorkloadSelectorBuilder().build());
  }
  public EnvoyFilterSpecFluentImpl.WorkloadSelectorNested<A> editOrNewWorkloadSelectorLike(WorkloadSelector item) {
    return withNewWorkloadSelectorLike(getWorkloadSelector() != null ? getWorkloadSelector(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterSpecFluentImpl that = (EnvoyFilterSpecFluentImpl) o;
    if (!java.util.Objects.equals(configPatches, that.configPatches)) return false;

    if (!java.util.Objects.equals(priority, that.priority)) return false;

    if (!java.util.Objects.equals(workloadSelector, that.workloadSelector)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(configPatches,  priority,  workloadSelector,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (configPatches != null) { sb.append("configPatches:"); sb.append(configPatches + ","); }
    if (priority != null) { sb.append("priority:"); sb.append(priority + ","); }
    if (workloadSelector != null) { sb.append("workloadSelector:"); sb.append(workloadSelector); }
    sb.append("}");
    return sb.toString();
  }
  class ConfigPatchesNestedImpl<N> extends EnvoyFilterEnvoyConfigObjectPatchFluentImpl<EnvoyFilterSpecFluentImpl.ConfigPatchesNested<N>> implements EnvoyFilterSpecFluentImpl.ConfigPatchesNested<N>,Nested<N>{
    ConfigPatchesNestedImpl(int index,EnvoyFilterEnvoyConfigObjectPatch item) {
      this.index = index;
      this.builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(this, item);
    }
    ConfigPatchesNestedImpl() {
      this.index = -1;
      this.builder = new EnvoyFilterEnvoyConfigObjectPatchBuilder(this);
    }
    EnvoyFilterEnvoyConfigObjectPatchBuilder builder;
    int index;
    public N and() {
      return (N) EnvoyFilterSpecFluentImpl.this.setToConfigPatches(index,builder.build());
    }
    public N endConfigPatch() {
      return and();
    }
    
  }
  class WorkloadSelectorNestedImpl<N> extends WorkloadSelectorFluentImpl<EnvoyFilterSpecFluentImpl.WorkloadSelectorNested<N>> implements EnvoyFilterSpecFluentImpl.WorkloadSelectorNested<N>,Nested<N>{
    WorkloadSelectorNestedImpl(WorkloadSelector item) {
      this.builder = new WorkloadSelectorBuilder(this, item);
    }
    WorkloadSelectorNestedImpl() {
      this.builder = new WorkloadSelectorBuilder(this);
    }
    WorkloadSelectorBuilder builder;
    public N and() {
      return (N) EnvoyFilterSpecFluentImpl.this.withWorkloadSelector(builder.build());
    }
    public N endWorkloadSelector() {
      return and();
    }
    
  }
  
}
